@@ -6,16 +6,16 @@ from requests_mock import Mocker
 from .authentication import OAuth2Mixin
 
 
-class AuthenticationMock(Mocker):
+class AuthenticationMocker(Mocker):
     def __init__(
             self,
-            username,
+            username=None,
             user_uuid=None,
             user_scope=None,
             access_token=None,
     ):
         super().__init__()
-        self.username = username
+        self.username = username or uuid.uuid4().hex
         self.user_uuid = user_uuid or uuid.uuid4().hex
         self.user_scope = (
             ' '.join(user_scope) if
@@ -42,3 +42,23 @@ class AuthenticationMock(Mocker):
                 }
             }),
         )
+
+
+def authentication_mock(pass_mocker=False, **mock_kwargs):
+    """
+    decorator for authentication mock
+    :param pass_mocker:
+    :param mock_kwargs:
+    :return:
+    """
+
+    def decorator(func):
+        def wrapped(**func_kwargs):
+            with AuthenticationMocker(**mock_kwargs) as m:
+                if pass_mocker:
+                    mock_kwargs['mocker'] = m
+                return func(**func_kwargs)
+
+        return wrapped
+
+    return decorator
