@@ -1,6 +1,11 @@
 from rest_framework import permissions
 
 
+class ReadOnlyPermission(permissions.BasePermission):
+    def has_permission(self, request, view):
+        return request.method in permissions.SAFE_METHODS
+
+
 class ScopesPermission(permissions.BasePermission):
     def has_permission(self, request, view):
         required_scopes = self.get_scopes(request, view)
